/*
 * Copyright 2005-2007 WSO2, Inc. (http://wso2.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.wsas.admin.service;

import org.apache.axis2.AxisFault;
import org.apache.axis2.context.ConfigurationContext;
import org.apache.axis2.context.MessageContext;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.wso2.utils.ServerException;
import org.wso2.wsas.ServerConstants;
import org.wso2.wsas.admin.service.util.ServerData;
import org.wso2.wsas.admin.service.util.ServerStatus;
import org.wso2.wsas.util.Controllable;


/**
 * Admin service to manage server related operations
 */
public class ServerAdmin extends AbstractAdmin {
    private static final Log log = LogFactory.getLog(ServerAdmin.class);
    private Controllable controllable;

    public ServerData getServerData() throws AxisFault {
        return new ServerData(ServerConstants.SERVER_NAME,
                              getAxisConfig().getRepository().toString());
    }

    public ServerStatus getStatus() throws AxisFault {
        ServerStatus serverStatus = new ServerStatus();
        serverStatus.update(getAxisConfig());
        return serverStatus;
    }

    public void restart() throws AxisFault {
        ConfigurationContext configurationContext =
                MessageContext.getCurrentMessageContext().getConfigurationContext();
        controllable =
                (Controllable) configurationContext.
                        getProperty(ServerConstants.WSO2WSAS_INSTANCE);
        Thread th = new Thread() {
            public void run() {
                try {
                    Thread.sleep(1000);
                    controllable.restart();
                } catch (Exception e) {
                    String msg = "Cannot restart server";
                    log.error(msg, e);
                    throw new RuntimeException(msg, e);
                }
            }
        };
        th.start();
    }

    public void restartGracefully() throws AxisFault {
        ConfigurationContext configurationContext =
                MessageContext.getCurrentMessageContext().getConfigurationContext();
        controllable =
                (Controllable) configurationContext.
                        getProperty(ServerConstants.WSO2WSAS_INSTANCE);
        Thread th = new Thread() {
            public void run() {
                try {
                    Thread.sleep(1000);
                    controllable.restartGracefully();
                } catch (Exception e) {
                    String msg = "Cannot restart server";
                    log.error(msg, e);
                    throw new RuntimeException(msg, e);
                }
            }
        };
        th.start();
    }

    public void shutdown() throws AxisFault {
        ConfigurationContext configurationContext =
                MessageContext.getCurrentMessageContext().getConfigurationContext();
        controllable =
                (Controllable) configurationContext.
                        getProperty(ServerConstants.WSO2WSAS_INSTANCE);
        Thread th = new Thread() {
            public void run() {
                try {
                    Thread.sleep(1000);
                    controllable.shutdown();
                } catch (Exception e) {
                    String msg = "Cannot shutdown server";
                    log.error(msg, e);
                    throw new RuntimeException(msg, e);
                }
            }
        };
        th.start();
    }

    public void shutdownGracefully() throws AxisFault {
        ConfigurationContext configurationContext =
                MessageContext.getCurrentMessageContext().getConfigurationContext();
        controllable =
                (Controllable) configurationContext.
                        getProperty(ServerConstants.WSO2WSAS_INSTANCE);
        Thread th = new Thread() {
            public void run() {
                try {
                    Thread.sleep(1000);
                    controllable.shutdownGracefully();
                } catch (Exception e) {
                    String msg = "Cannot gracefully shutdown server";
                    log.error(msg, e);
                    throw new RuntimeException(msg, e);
                }
            }
        };
        th.start();
    }
}
