/*                                                                             
 * Copyright 2004,2005 The Apache Software Foundation.                         
 *                                                                             
 * Licensed under the Apache License, Version 2.0 (the "License");             
 * you may not use this file except in compliance with the License.            
 * You may obtain a copy of the License at                                     
 *                                                                             
 *      http://www.apache.org/licenses/LICENSE-2.0                             
 *                                                                             
 * Unless required by applicable law or agreed to in writing, software         
 * distributed under the License is distributed on an "AS IS" BASIS,           
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.    
 * See the License for the specific language governing permissions and         
 * limitations under the License.                                              
 */
package org.wso2.wsas;

/**
 *
 */
public interface ServerManagementMBean {

    /**
     * Method to switch a node to maintenance mode.
     * <p/>
     * Here is the sequence of events:
     * <p/>
     * <oll>
     * <li>Client calls this method</li>
     * <li>The server stops accepting new requests/connections, but continues to stay alive so
     * that old requests & connections can be served</li>
     * <li>Once all requests have been processed, the method returns</li
     * </ol>
     *
     * @return An appropriate message
     * @throws Exception  If an error occurred while switching to maintenace mode
     */
    String startMaintenance() throws Exception;

    /**
     * Method to change the state of a node from "maintenance" to "normal"
     *
     * @return An appropriate message
     * @throws Exception  If an error occurred while switching to normal mode
     */
    String endMaintenance() throws Exception;

    /**
     * Method to check whether this WSAS instance is alive
     *
     * @return True
     */
    boolean isAlive();

}
